#PBS -l nodes=1:ppn=16
#PBS -o stdout.log
#PBS -e stderr.log
#PBS -l walltime=0:15:0

from ase.io import read
from gpaw import GPAW, Mixer, FermiDirac
from gpaw.xc.libvdwxc import vdw_df_cx
from gpaw.mpi import world
from gpaw.utilities import h2gpts
from gpaw.utilities.timing import ParallelTimer

system = read('small.xyz')
system.center(vacuum=2.0)
system = system.repeat((2, 2, 2))

nnodes = world.size // 16


options = {1: (4, 4, 4),
           2: (8, 4, 4),
           3: (8, 6, 4),
           4: (8, 8, 4),
           6: (12, 8, 4),
           8: (8, 16, 4)}

na, nb, band = options[nnodes]
assert na * nb == world.size

if nnodes == 1:
    na = 4
    nb = 4
    band = 2
elif nnodes == 2:
    na = 8
    nb = 4
    band = 4
elif nnodes == 3:
    pass
elif nnodes == 4:
    pass


calc = GPAW(mode='lcao',
            basis={'H': 'sz(dzp)',
                   'N': 'szp(dzp)',
                   'S': 'szp(dzp)',
                   'C': 'szp(dzp)',
                   'Au': 'dzp'},
            nbands='105%',
            gpts=h2gpts(0.17, system.get_cell(), idiv=32),
            timer=ParallelTimer(),
            parallel=dict(sl_default=(na, nb, 64), band=band),
            poissonsolver=PoissonSolver(relax='GS'),
            occupations=FermiDirac(0.1),
            xc=vdw_df_cx())
